Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3254)

Unified Diff: chrome/browser/ui/libgtk2ui/gtk2_ui.h

Issue 2375543003: Add SetProminent() to MdTextButton to create blue buttons. (Closed)
Patch Set: Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/libgtk2ui/gtk2_ui.h
diff --git a/chrome/browser/ui/libgtk2ui/gtk2_ui.h b/chrome/browser/ui/libgtk2ui/gtk2_ui.h
index e98ddfee39e3fbe1b6915ed649e393e5c93f1719..3822dcd8eb695560ad6cb8a2325ef9b1abb85753 100644
--- a/chrome/browser/ui/libgtk2ui/gtk2_ui.h
+++ b/chrome/browser/ui/libgtk2ui/gtk2_ui.h
@@ -151,8 +151,8 @@ class Gtk2UI : public views::LinuxUI {
// entry.
void GetSelectedEntryForegroundHSL(color_utils::HSL* tint) const;
- // Gets a color for the background of the call to action button.
- SkColor CallToActionBgColor(int gtk_state) const;
+ // Gets a color for the background of the prominent button.
+ SkColor ProminentButtonBgColor(int gtk_state) const;
sky 2016/09/27 17:38:32 optional: prefix with Get (just like GetSelectedEn
shrike 2016/09/27 17:52:51 Done.
// Updates |default_font_*|.
void UpdateDefaultFont();

Powered by Google App Engine
This is Rietveld 408576698